@@ -1747,8 +1747,16 @@ class VariableClUpdateWithBdepsOptSet(Variable):
     opt = ["--with-bdeps"]
 
     def init(self):
-        self.help = _("Save packages used during build")
-        self.label = _("save packages used during build")
+        self.help = _("save packages used during build")
+        self.label = _("Save packages used during build")
 
     def get(self):
         return self.Get('cl_update_with_bdeps_set')
+
+
+class VariableClUpdateForceDepcleanSet(Variable):
+    """
+    Принудительный вызов depclean
+    """
+    type = "bool"
+    value = "off"
